@@ -66,14 +66,14 @@ function(strings.vec, low = 10){
 
    subStr_all_result.df <- as.data.frame(table(unlist(subStr_all.df)))
 
-   names(subStr_all_result.df) <- c("Pattern", "Freq_grp")
+   names(subStr_all_result.df) <- c("Pattern", "Freq_total")
 
    # in case substring starting w/ '0'.
    subStr_all_result.df$Pattern <- as.character(subStr_all_result.df$Pattern)
 
    # 4.2 Ratio of number of each substring to number of original full strings
 
-   pattRatio <- subStr_all_result.df$Freq_grp/numStrings
+   pattRatio <- subStr_all_result.df$Freq_total/numStrings
 
    # 4.3 function to write as percent format
 
@@ -84,7 +84,7 @@ function(strings.vec, low = 10){
    # 4.4 more columns
 
    # Percentage in % and digit formats, respectively
-   subStr_all_result.df$Percent_grp <- percent(pattRatio) # column of ratio in percent
+   subStr_all_result.df$Percent_total <- percent(pattRatio) # column of ratio in percent
    subStr_all_result.df$pattRatio <- pattRatio            # column of ratio in digits
    subStr_all_result.df$pattRatio <- format(subStr_all_result.df$pattRatio, digits = 2, nsmall = 2)
 
@@ -153,7 +153,7 @@ function(strings.vec, low = 10){
 
    ##### 6. Combine all and once to all.
 
-   # 6.1 Duplicate the 'all' df
+   # 6.1 Copy the 'all' df
 
    subStr_result_out.df <- subStr_all_result.df
 
@@ -165,7 +165,7 @@ function(strings.vec, low = 10){
    # 6.2.1 Sort substring length (long to short), then frequency (high to low)
 
    subStr_result_out.df <- subStr_result_out.df[with(subStr_result_out.df,
-         order(-subStr_result_out.df$Length, -subStr_result_out.df$Freq_grp)),]
+         order(-subStr_result_out.df$Length, -subStr_result_out.df$Freq_total)),]
 
 
    # 6.3 use only pattRatio >=low, then remove the ratio column (no conversion to token)
